==> keystone-4.0.0-rc.0.tgz: package/website/data/navigation.js <==
export const gettingStarted = {
	section: 'Starting',
	slug: '/getting-started',
	items: [{
		label: 'Getting Started',
		slug: '',
	}, {
		label: 'Keystone Yeoman Generator',
		slug: '/yo-generator',
	}, {
		section: 'Setting Up',
		slug: '/setting-up',
		items: [{
			label: 'Part 1: Initial Setup',
			slug: '/part-1',
		}, {
			label: 'Part 2 - Database Setup',
			slug: '/part-2',
		}, {
			label: 'Part 3: Routing',
			slug: '/part-3',
		}, {
			label: 'Part 4 -  Adding data to the database from a form',
			slug: '/part-4',
		}],
	}],
};
export const guides = {
	section: 'Guides',
	slug: '/guides',
	items: [{
		label: 'Guides Index',
		slug: '',
	}, {
		label: 'Upgrade Guide: 0.3 to 4.0',
		slug: '/v-0-3-to-v-4-0-upgrade-guide',
	}, {
		label: 'API File and Image Uploads',
		slug: '/api-file-image-uploads',
	}, {
		label: 'How to create a blog with Keystone',
		slug: '/how-to-create-a-blog-with-keystone',
	}, {
		label: 'How to send emails with Keystone',
		slug: '/how-to-send-emails',
	}],
};
export const documentation = {
	section: 'Docs',
	slug: '/documentation',
	items: [{
		label: 'Introduction',
		slug: '',
	}, {
		section: 'Initialisation Options',
		slug: '/configuration',
		items: [{
			label: 'Configuration',
			slug: '',
		}, {
			label: 'Project Options',
			slug: '/project-options',
		}, {
			label: 'Server Options',
			slug: '/server-options',
		}, {
			label: 'Database Options',
			slug: '/database-options',
		}, {
			label: 'Admin UI Option',
			slug: '/server-options',
		}],
	}, {
		section: 'Database',
		slug: '/database',
		items: [{
			label: 'Database Configuration',
			slug: '',
		}, {
			label: 'Relationships',
			slug: '/relationships',
		}, {
			label: 'Database Updates',
			slug: '/application-updates',
		}],
	}],
};
export const api = {
	section: 'API',
	slug: '/api',
	items: [
		{
			label: 'Introduction',
			slug: '',
		}, {
			section: 'List',
			slug: '/list',
			items: [{
				label: 'Creating a List',
				slug: '',
			}, {
				label: 'add()',
				slug: '/add',
			}, {
				label: 'Model',
				slug: '/model',
			}, {
				label: 'List Construction Options',
				slug: '/options',
			}, {
				label: 'register()',
				slug: '/register',
			}, {
				label: 'Schema',
				slug: '/schema',
			}, {
				label: 'updateItem()',
				slug: '/update-item',
			}],
		}, {
			section: 'Methods',
			slug: '/methods',
			items: [{
				label: 'openDatabaseConnection()',
				slug: '/close-database-connection',
			}, {
				label: 'createItems()',
				slug: '/create-items',
			}, {
				label: 'createRouter()',
				slug: '/create-router',
			}, {
				label: 'get()',
				slug: '/get',
			}, {
				label: 'import()',
				slug: '/import',
			}, {
				label: 'importer()',
				slug: '/importer',
			}, {
				label: 'init()',
				slug: '/init',
			}, {
				label: 'list()',
				slug: '/list',
			}, {
				label: 'middleware()',
				slug: '/middleware',
			}, {
				label: 'openDatabaseConnection()',
				slug: '/open-database-connection',
			}, {
				label: 'paginate()',
				slug: '/paginate',
			}, {
				label: 'pre()',
				slug: '/pre',
			}, {
				label: 'set()',
				slug: '/set',
			}, {
				label: 'start()',
				slug: '/start',
			}, {
				label: 'updateHandler()',
				slug: '/update-handler',
			}],
		}, {
			section: 'View',
			slug: '/view',
			items: [{
				label: 'on',
				slug: '/on',
			}, {
				label: 'query',
				slug: '/query',
			}, {
				label: 'render',
				slug: '/render',
			}],
		}, {
			section: 'Field Types',
			slug: '/field',
			items: [{
				label: 'Field Options',
				slug: '/options',
			}, {
				label: 'Underscore Methods',
				slug: '/underscore-methods',
			}, {
				label: 'AzureFile',
				slug: '/azurefile',
			}, {
				label: 'Embedly',
				slug: '/embedly',
			}, {
				label: 'File',
				slug: '/file',
			}, {
				label: 'LocalFile',
				slug: '/localfile',
			}, {
				label: 'Local Files',
				slug: '/localfiles',
			}, {
				label: 'S3 File',
				slug: '/s-3-file',
			}, {
				label: 'Boolean',
				slug: '/boolean',
			}, {
				label: 'CloudinaryImage',
				slug: '/cloudinaryimage',
			}, {
				label: 'CloudinaryImages',
				slug: '/cloudinaryimages',
			}, {
				label: 'Code',
				slug: '/code',
			}, {
				label: 'Date',
				slug: '/date',
			}, {
				label: 'Color',
				slug: '/color',
			}, {
				label: 'Datearray field',
				slug: '/datearray',
			}, {
				label: 'DateTime',
				slug: '/datetime',
			}, {
				label: 'Email',
				slug: '/email',
			}, {
				label: 'GeoPoint',
				slug: '/geopoint',
			}, {
				label: 'HTML',
				slug: '/html',
			}, {
				label: 'Key',
				slug: '/key',
			}, {
				label: 'Location',
				slug: '/location',
			}, {
				label: 'Markdown',
				slug: '/markdown',
			}, {
				label: 'Money',
				slug: '/money',
			}, {
				label: 'Name',
				slug: '/name',
			}, {
				label: 'Number',
				slug: '/number',
			}, {
				label: 'NumberArray field',
				slug: '/numberarray',
			}, {
				label: 'Password',
				slug: '/password',
			}, {
				label: 'Relationship',
				slug: '/relationship',
			}, {
				label: 'Select',
				slug: '/select',
			}, {
				label: 'Text',
				slug: '/text',
			}, {
				label: 'Textarea',
				slug: '/textarea',
			}, {
				label: 'Textarray',
				slug: '/textarray',
			}, {
				label: 'URL',
				slug: '/url',
			}],
		},
	],
};

==> keystone-4.2.0.tgz: package/website/data/navigation.js <==
export const gettingStarted = {
	section: 'Get started',
	slug: '/getting-started',
	items: [{
		label: 'What is Keystone?',
		slug: '',
	}, {
		label: 'Quick Start (yo keystone)',
		slug: '/yo-generator',
	}, {
		section: 'Setting Up From Scratch',
		slug: '/setting-up',
		items: [{
			label: 'Part 1: Initial Setup',
			slug: '/part-1',
		}, {
			label: 'Part 2: Data Model Setup',
			slug: '/part-2',
		}, {
			label: 'Part 3: Routing',
			slug: '/part-3',
		}, {
			label: 'Part 4: Adding data from a form',
			slug: '/part-4',
		}],
	}],
};
export const guides = {
	section: 'Guides',
	slug: '/guides',
	items: [{
		label: 'Guides Index',
		slug: '',
	}, {
		label: 'Upgrade Guide: 0.3 to 4.0',
		slug: '/v-0-3-to-v-4-0-upgrade-guide',
	}, {
		label: 'API File and Image Uploads',
		slug: '/api-file-image-uploads',
	}, {
		label: 'How to create a blog with Keystone',
		slug: '/how-to-create-a-blog-with-keystone',
	}, {
		label: 'How to send emails with Keystone',
		slug: '/how-to-send-emails',
	}],
};
export const documentation = {
	section: 'Docs',
	slug: '/documentation',
	items: [{
		label: 'Introduction',
		slug: '',
	}, {
		section: 'Initialisation Options',
		slug: '/configuration',
		items: [{
			label: 'Configuration',
			slug: '',
		}, {
			label: 'Project Options',
			slug: '/project-options',
		}, {
			label: 'Server Options',
			slug: '/server-options',
		}, {
			label: 'Database Options',
			slug: '/database-options',
		}, {
			label: 'Admin UI Option',
			slug: '/admin-ui-options',
		}],
	}, {
		section: 'Database',
		slug: '/database',
		items: [{
			label: 'Database Configuration',
			slug: '',
		}, {
			label: 'Relationships',
			slug: '/relationships',
		}, {
			label: 'Application Updates',
			slug: '/application-updates',
		}],
	}],
};
export const api = {
	section: 'API',
	slug: '/api',
	items: [
		{
			label: 'Introduction',
			slug: '',
		}, {
			section: 'List',
			slug: '/list',
			items: [{
				label: 'Creating a List',
				slug: '',
			}, {
				label: 'add()',
				slug: '/add',
			}, {
				label: 'Model',
				slug: '/model',
			}, {
				label: 'List Construction Options',
				slug: '/options',
			}, {
				label: 'register()',
				slug: '/register',
			}, {
				label: 'Schema',
				slug: '/schema',
			}, {
				label: 'updateItem()',
				slug: '/update-item',
			}],
		}, {
			section: 'Methods',
			slug: '/methods',
			items: [{
				label: 'closeDatabaseConnection()',
				slug: '/close-database-connection',
			}, {
				label: 'createItems()',
				slug: '/create-items',
			}, {
				label: 'createRouter()',
				slug: '/create-router',
			}, {
				label: 'get()',
				slug: '/get',
			}, {
				label: 'import()',
				slug: '/import',
			}, {
				label: 'importer()',
				slug: '/importer',
			}, {
				label: 'init()',
				slug: '/init',
			}, {
				label: 'list()',
				slug: '/list',
			}, {
				label: 'middleware()',
				slug: '/middleware',
			}, {
				label: 'openDatabaseConnection()',
				slug: '/open-database-connection',
			}, {
				label: 'paginate()',
				slug: '/paginate',
			}, {
				label: 'pre()',
				slug: '/pre',
			}, {
				label: 'set()',
				slug: '/set',
			}, {
				label: 'start()',
				slug: '/start',
			}, {
				label: 'updateHandler()',
				slug: '/update-handler',
			}],
		}, {
			section: 'View',
			slug: '/view',
			items: [{
				label: 'on',
				slug: '/on',
			}, {
				label: 'query',
				slug: '/query',
			}, {
				label: 'render',
				slug: '/render',
			}],
		}, {
			section: 'Field Types',
			slug: '/field',
			items: [{
				label: 'Field Options',
				slug: '/options',
			}, {
				label: 'Underscore Methods',
				slug: '/underscore-methods',
			}, {
				label: 'AzureFile',
				slug: '/azurefile',
			}, {
				label: 'Embedly',
				slug: '/embedly',
			}, {
				label: 'File',
				slug: '/file',
			}, {
				label: 'LocalFile',
				slug: '/localfile',
			}, {
				label: 'LocalFiles',
				slug: '/localfiles',
			}, {
				label: 'S3 File',
				slug: '/s-3-file',
			}, {
				label: 'Boolean',
				slug: '/boolean',
			}, {
				label: 'CloudinaryImage',
				slug: '/cloudinaryimage',
			}, {
				label: 'CloudinaryImages',
				slug: '/cloudinaryimages',
			}, {
				label: 'Code',
				slug: '/code',
			}, {
				label: 'Date',
				slug: '/date',
			}, {
				label: 'Color',
				slug: '/color',
			}, {
				label: 'Datearray field',
				slug: '/datearray',
			}, {
				label: 'DateTime',
				slug: '/datetime',
			}, {
				label: 'Email',
				slug: '/email',
			}, {
				label: 'GeoPoint',
				slug: '/geopoint',
			}, {
				label: 'HTML',
				slug: '/html',
			}, {
				label: 'Key',
				slug: '/key',
			}, {
				label: 'Location',
				slug: '/location',
			}, {
				label: 'Markdown',
				slug: '/markdown',
			}, {
				label: 'Money',
				slug: '/money',
			}, {
				label: 'Name',
				slug: '/name',
			}, {
				label: 'Number',
				slug: '/number',
			}, {
				label: 'NumberArray field',
				slug: '/numberarray',
			}, {
				label: 'Password',
				slug: '/password',
			}, {
				label: 'Relationship',
				slug: '/relationship',
			}, {
				label: 'Select',
				slug: '/select',
			}, {
				label: 'Text',
				slug: '/text',
			}, {
				label: 'Textarea',
				slug: '/textarea',
			}, {
				label: 'TextArray',
				slug: '/textarray',
			}, {
				label: 'URL',
				slug: '/url',
			}],
		},
	],
};
